@@ -3,8 +3,8 @@ use core::marker::PhantomData;
 use core::mem;
 use core::ptr;
 use core::result::Result;
+use core::slice;
 use core::time::Duration;
-use std::ptr::NonNull;
 
 extern crate alloc;
 use alloc::boxed::Box;
@@ -148,6 +148,23 @@ impl<'a> EspEventPostData {
             payload_len: mem::size_of::<P>(),
         }
     }
+
+    /// # Safety
+    ///
+    /// Care should be taken to only call this function with payload reference that lives at least as long as
+    /// the call that will post this data to the event loop
+    pub unsafe fn new_raw(
+        source: *const c_types::c_char,
+        event_id: Option<i32>,
+        payload: &[u32],
+    ) -> EspEventPostData {
+        Self {
+            source,
+            event_id: event_id.unwrap_or(0),
+            payload: payload.as_ptr() as *const _,
+            payload_len: payload.len(),
+        }
+    }
 }
 
 pub struct EspEventFetchData {
@@ -165,13 +182,21 @@ impl EspEventFetchData {
         let payload: &P = if mem::size_of::<P>() > 0 {
             self.payload as *const P
         } else {
-            NonNull::dangling().as_ptr() as *const P
+            ptr::NonNull::dangling().as_ptr() as *const P
         }
         .as_ref()
         .unwrap();
 
         payload
     }
+
+    /// # Safety
+    ///
+    /// Care should be taken to only call this function on fetch data that one is certain to be
+    /// of length `len`
+    pub unsafe fn as_raw_payload(&self, len: usize) -> &[u8] {
+        slice::from_raw_parts(self.payload as *const _, len)
+    }
 }
 
 struct UnsafeCallback(*mut Box<dyn for<'a> FnMut(&'a EspEventFetchData) + 'static>);
@@ -778,7 +803,7 @@ where
 
 #[cfg(feature = "experimental")]
 mod nonblocking {
-    use embedded_svc::utils::nonblocking::event_bus::Channel;
+    use embedded_svc::utils::nonblocking::event_bus::AsyncEventBus;
     use embedded_svc::utils::nonblocking::{Asyncify, UnblockingAsyncify};
 
     use esp_idf_hal::mutex::Condvar;
@@ -787,21 +812,21 @@ mod nonblocking {
     where
         T: super::EspEventLoopType,
     {
-        type AsyncWrapper<S> = Channel<(), Condvar, S>;
+        type AsyncWrapper<S> = AsyncEventBus<(), Condvar, S>;
     }
 
     impl<T> UnblockingAsyncify for super::EspEventLoop<T>
     where
         T: super::EspEventLoopType,
     {
-        type AsyncWrapper<U, S> = Channel<U, Condvar, S>;
+        type AsyncWrapper<U, S> = AsyncEventBus<U, Condvar, S>;
     }
 
     impl<M, P, L> Asyncify for super::EspTypedEventLoop<M, P, L> {
-        type AsyncWrapper<S> = Channel<(), Condvar, S>;
+        type AsyncWrapper<S> = AsyncEventBus<(), Condvar, S>;
     }
 
     impl<M, P, L> UnblockingAsyncify for super::EspTypedEventLoop<M, P, L> {
-        type AsyncWrapper<U, S> = Channel<U, Condvar, S>;
+        type AsyncWrapper<U, S> = AsyncEventBus<U, Condvar, S>;
     }
 }
